@@ -7,6 +7,8 @@ import simplejson
 
 from base64 import b64encode, b64decode
 
+
+from tiddlyweb.specialbag import get_bag_retriever
 from tiddlyweb.serializer import TiddlerFormatError
 from tiddlyweb.serializations import SerializationInterface
 from tiddlyweb.model.policy import Policy
@@ -58,8 +60,13 @@ class Serialization(SerializationInterface):
             line = ''
             if not isinstance(bag, basestring):
                 bag = bag.name
-            line += '/bags/%s/tiddlers' % urllib.quote(
-                    bag.encode('utf-8'), safe='')
+            if not get_bag_retriever(self.environ, bag):
+                # If there is a retriever for this bag name then
+                # we want to write its name straight.
+                line += '/bags/%s/tiddlers' % urllib.quote(
+                        bag.encode('utf-8'), safe='')
+            else:
+                line += bag
             if filter_string:
                 line += '?%s' % filter_string
             lines.append(line)
@@ -177,8 +184,11 @@ class Serialization(SerializationInterface):
                 else:
                     bag = line
                     filter_string = ''
-                bagname = bag.split('/')[2]
-                bagname = urllib.unquote(bagname.encode('utf-8'))
-                bagname = bagname.decode('utf-8')
+                if bag.startswith('/bags/'):
+                    bagname = bag.split('/')[2]
+                    bagname = urllib.unquote(bagname.encode('utf-8'))
+                    bagname = bagname.decode('utf-8')
+                else:
+                    bagname = bag
                 recipe_lines.append((bagname, filter_string))
         return recipe_lines
